@@ -6,18 +6,17 @@ module RuboCop
       # Checks that left braces for adjacent single line lets are aligned.
       #
       # @example
+      #   # bad
+      #   let(:foobar) { blahblah }
+      #   let(:baz) { bar }
+      #   let(:a) { b }
       #
-      #     # bad
-      #     let(:foobar) { blahblah }
-      #     let(:baz) { bar }
-      #     let(:a) { b }
+      #   # good
+      #   let(:foobar) { blahblah }
+      #   let(:baz)    { bar }
+      #   let(:a)      { b }
       #
-      #     # good
-      #     let(:foobar) { blahblah }
-      #     let(:baz)    { bar }
-      #     let(:a)      { b }
-      #
-      class AlignLeftLetBrace < Cop
+      class AlignLeftLetBrace < Base
         extend AutoCorrector
 
         MSG = 'Align left let brace'
@@ -27,11 +26,9 @@ module RuboCop
         end
 
         def on_new_investigation
+          super
           return if processed_source.blank?
 
-          token_aligner =
-            RuboCop::RSpec::AlignLetBrace.new(processed_source.ast, :begin)
-
           token_aligner.offending_tokens.each do |let|
             add_offense(let.loc.begin) do |corrector|
               corrector.insert_before(
@@ -40,6 +37,12 @@ module RuboCop
             end
           end
         end
+
+        private
+
+        def token_aligner
+          RuboCop::RSpec::AlignLetBrace.new(processed_source.ast, :begin)
+        end
       end
     end
   end
