@@ -25,21 +25,29 @@ module RuboCop
       #     some_method
       #     test.run
       #   end
-      class AroundBlock < Cop
+      #
+      class AroundBlock < Base
         MSG_NO_ARG     = 'Test object should be passed to around block.'
-        MSG_UNUSED_ARG = 'You should call `%<arg>s.call` '\
+        MSG_UNUSED_ARG = 'You should call `%<arg>s.call` ' \
                          'or `%<arg>s.run`.'
 
-        def_node_matcher :hook, <<-PATTERN
-          (block {(send nil? :around) (send nil? :around sym)} (args $...) ...)
+        # @!method hook_block(node)
+        def_node_matcher :hook_block, <<-PATTERN
+          (block (send nil? :around sym ?) (args $...) ...)
         PATTERN
 
+        # @!method hook_numblock(node)
+        def_node_matcher :hook_numblock, <<-PATTERN
+          (numblock (send nil? :around sym ?) ...)
+        PATTERN
+
+        # @!method find_arg_usage(node)
         def_node_search :find_arg_usage, <<-PATTERN
           {(send $... {:call :run}) (send _ _ $...) (yield $...) (block-pass $...)}
         PATTERN
 
         def on_block(node)
-          hook(node) do |(example_proxy)|
+          hook_block(node) do |(example_proxy)|
             if example_proxy.nil?
               add_no_arg_offense(node)
             else
@@ -48,6 +56,12 @@ module RuboCop
           end
         end
 
+        def on_numblock(node)
+          hook_numblock(node) do
+            check_for_numblock(node)
+          end
+        end
+
         private
 
         def add_no_arg_offense(node)
@@ -66,6 +80,17 @@ module RuboCop
             message: format(MSG_UNUSED_ARG, arg: name)
           )
         end
+
+        def check_for_numblock(block)
+          find_arg_usage(block) do |usage|
+            return if usage.include?(s(:lvar, :_1))
+          end
+
+          add_offense(
+            block.children.last,
+            message: format(MSG_UNUSED_ARG, arg: :_1)
+          )
+        end
       end
     end
   end
