@@ -10,7 +10,6 @@ module RuboCop
       # cases it's better to specify what exactly is the expected value.
       #
       # @example
-      #
       #   # bad
       #   expect(foo).to be
       #
@@ -19,11 +18,14 @@ module RuboCop
       #   expect(foo).to be 1.0
       #   expect(foo).to be(true)
       #
-      class Be < Cop
-        MSG = 'Don\'t use `be` without an argument.'
+      class Be < Base
+        MSG = "Don't use `be` without an argument."
 
+        RESTRICT_ON_SEND = Runners.all
+
+        # @!method be_without_args(node)
         def_node_matcher :be_without_args, <<-PATTERN
-          (send _ #{Runners::ALL.node_pattern_union} $(send nil? :be))
+          (send _ #Runners.all $(send nil? :be))
         PATTERN
 
         def on_send(node)
