@@ -10,8 +10,10 @@ module RuboCop
       # can be compared by identity and therefore the `be` matcher is
       # preferable as it is a more strict test.
       #
-      # @example
+      # @safety
+      #   This cop is unsafe because it changes how values are compared.
       #
+      # @example
       #   # bad
       #   expect(foo).to eql(1)
       #   expect(foo).to eql(1.0)
@@ -35,13 +37,15 @@ module RuboCop
       # necessarily the same type as `b` since the `#==` operator can
       # coerce objects for comparison.
       #
-      class BeEql < Cop
+      class BeEql < Base
         extend AutoCorrector
 
         MSG = 'Prefer `be` over `eql`.'
+        RESTRICT_ON_SEND = %i[to].freeze
 
+        # @!method eql_type_with_identity(node)
         def_node_matcher :eql_type_with_identity, <<-PATTERN
-          (send _ :to $(send nil? :eql {true false int float sym nil_type?}))
+          (send _ :to $(send nil? :eql {true false int float sym nil}))
         PATTERN
 
         def on_send(node)
