@@ -6,47 +6,62 @@ module RuboCop
       module Capybara
         # Checks that no expectations are set on Capybara's `current_path`.
         #
-        # The `have_current_path` matcher (https://www.rubydoc.info/github/
-        # teamcapybara/capybara/master/Capybara/RSpecMatchers#have_current_path-
-        # instance_method) should be used on `page` to set expectations on
-        # Capybara's current path, since it uses Capybara's waiting
-        # functionality (https://github.com/teamcapybara/capybara/blob/master/
-        # README.md#asynchronous-javascript-ajax-and-friends) which ensures that
-        # preceding actions (like `click_link`) have completed.
+        # The
+        # https://www.rubydoc.info/github/teamcapybara/capybara/master/Capybara/RSpecMatchers#have_current_path-instance_method[`have_current_path` matcher]
+        # should be used on `page` to set expectations on Capybara's
+        # current path, since it uses
+        # https://github.com/teamcapybara/capybara/blob/master/README.md#asynchronous-javascript-ajax-and-friends[Capybara's waiting functionality]
+        # which ensures that preceding actions (like `click_link`) have
+        # completed.
+        #
+        # This cop does not support autocorrection in some cases.
         #
         # @example
         #   # bad
         #   expect(current_path).to eq('/callback')
-        #   expect(page.current_path).to match(/widgets/)
         #
         #   # good
-        #   expect(page).to have_current_path("/callback")
-        #   expect(page).to have_current_path(/widgets/)
+        #   expect(page).to have_current_path('/callback')
         #
-        class CurrentPathExpectation < Cop
+        #   # bad (does not support autocorrection)
+        #   expect(page.current_path).to match(variable)
+        #
+        #   # good
+        #   expect(page).to have_current_path('/callback')
+        #
+        class CurrentPathExpectation < ::RuboCop::Cop::Base
           extend AutoCorrector
 
           MSG = 'Do not set an RSpec expectation on `current_path` in ' \
                 'Capybara feature specs - instead, use the ' \
                 '`have_current_path` matcher on `page`'
 
+          RESTRICT_ON_SEND = %i[expect].freeze
+
+          # @!method expectation_set_on_current_path(node)
           def_node_matcher :expectation_set_on_current_path, <<-PATTERN
             (send nil? :expect (send {(send nil? :page) nil?} :current_path))
           PATTERN
 
           # Supported matchers: eq(...) / match(/regexp/) / match('regexp')
+          # @!method as_is_matcher(node)
           def_node_matcher :as_is_matcher, <<-PATTERN
             (send
-              #expectation_set_on_current_path $#{Runners::ALL.node_pattern_union}
+              #expectation_set_on_current_path ${:to :to_not :not_to}
               ${(send nil? :eq ...) (send nil? :match (regexp ...))})
           PATTERN
 
+          # @!method regexp_str_matcher(node)
           def_node_matcher :regexp_str_matcher, <<-PATTERN
             (send
-              #expectation_set_on_current_path $#{Runners::ALL.node_pattern_union}
+              #expectation_set_on_current_path ${:to :to_not :not_to}
               $(send nil? :match (str $_)))
           PATTERN
 
+          def self.autocorrect_incompatible_with
+            [Style::TrailingCommaInArguments]
+          end
+
           def on_send(node)
             expectation_set_on_current_path(node) do
               add_offense(node.loc.selector) do |corrector|
