@@ -40,12 +40,14 @@ module RuboCop
         #       # ...
         #     end
         #   end
-        class FeatureMethods < Cop
+        #
+        class FeatureMethods < Base
           extend AutoCorrector
+          include InsideExampleGroup
 
           MSG = 'Use `%<replacement>s` instead of `%<method>s`.'
 
-          # https://git.io/v7Kwr
+          # https://github.com/teamcapybara/capybara/blob/e283c1aeaa72441f5403963577e16333bf111a81/lib/capybara/rspec/features.rb#L31-L36
           MAP = {
             background: :before,
             scenario:   :it,
@@ -55,20 +57,20 @@ module RuboCop
             feature:    :describe
           }.freeze
 
-          def_node_matcher :spec?, <<-PATTERN
-            (block
-              (send #{RSPEC} {:describe :feature} ...)
-            ...)
+          # @!method capybara_speak(node)
+          def_node_matcher :capybara_speak, <<-PATTERN
+            {#{MAP.keys.map(&:inspect).join(' ')}}
           PATTERN
 
+          # @!method feature_method(node)
           def_node_matcher :feature_method, <<-PATTERN
             (block
-              $(send #{RSPEC} ${#{MAP.keys.map(&:inspect).join(' ')}} ...)
+              $(send #rspec? $#capybara_speak ...)
             ...)
           PATTERN
 
-          def on_block(node)
-            return unless inside_spec?(node)
+          def on_block(node) # rubocop:disable InternalAffairs/NumblockHandler
+            return unless inside_example_group?(node)
 
             feature_method(node) do |send_node, match|
               next if enabled?(match)
@@ -86,21 +88,6 @@ module RuboCop
 
           private
 
-          def inside_spec?(node)
-            return spec?(node) if root_node?(node)
-
-            root = node.ancestors.find { |parent| root_node?(parent) }
-            spec?(root)
-          end
-
-          def root_node?(node)
-            node.parent.nil? || root_with_siblings?(node.parent)
-          end
-
-          def root_with_siblings?(node)
-            node.begin_type? && node.parent.nil?
-          end
-
           def enabled?(method_name)
             enabled_methods.include?(method_name)
           end
