@@ -23,16 +23,18 @@ module RuboCop
       #   describe '.foo_bar' do
       #     # ...
       #   end
-      class ContextMethod < Cop
+      #
+      class ContextMethod < Base
         extend AutoCorrector
 
         MSG = 'Use `describe` for testing methods.'
 
+        # @!method context_method(node)
         def_node_matcher :context_method, <<-PATTERN
-          (block (send #{RSPEC} :context $(str #method_name?) ...) ...)
+          (block (send #rspec? :context $(str #method_name?) ...) ...)
         PATTERN
 
-        def on_block(node)
+        def on_block(node)  # rubocop:disable InternalAffairs/NumblockHandler
           context_method(node) do |context|
             add_offense(context) do |corrector|
               corrector.replace(node.send_node.loc.selector, 'describe')
