@@ -11,7 +11,7 @@ module RuboCop
       # This cop can be configured using the `EnforcedStyle` and `SkipBlocks`
       # options.
       #
-      # @example `EnforcedStyle: described_class`
+      # @example `EnforcedStyle: described_class` (default)
       #   # bad
       #   describe MyClass do
       #     subject { MyClass.do_something }
@@ -54,31 +54,35 @@ module RuboCop
       #     end
       #   end
       #
-      class DescribedClass < Cop
+      class DescribedClass < Base
         extend AutoCorrector
         include ConfigurableEnforcedStyle
+        include Namespace
 
         DESCRIBED_CLASS = 'described_class'
         MSG             = 'Use `%<replacement>s` instead of `%<src>s`.'
 
+        # @!method common_instance_exec_closure?(node)
         def_node_matcher :common_instance_exec_closure?, <<-PATTERN
           (block (send (const nil? {:Class :Module :Struct}) :new ...) ...)
         PATTERN
 
-        def_node_matcher :rspec_block?,
-                         RuboCop::RSpec::Language::ALL.block_pattern
+        # @!method rspec_block?(node)
+        def_node_matcher :rspec_block?, block_pattern('#ALL.all')
 
+        # @!method scope_changing_syntax?(node)
         def_node_matcher :scope_changing_syntax?, '{def class module}'
 
+        # @!method described_constant(node)
         def_node_matcher :described_constant, <<-PATTERN
           (block (send _ :describe $(const ...) ...) (args) $_)
         PATTERN
 
-        def_node_search :contains_described_class?, <<-PATTERN
-          (send nil? :described_class)
-        PATTERN
+        # @!method contains_described_class?(node)
+        def_node_search :contains_described_class?,
+                        '(send nil? :described_class)'
 
-        def on_block(node)
+        def on_block(node) # rubocop:disable InternalAffairs/NumblockHandler
           # In case the explicit style is used, we need to remember what's
           # being described.
           @described_class, body = described_constant(node)
@@ -125,29 +129,26 @@ module RuboCop
         end
 
         def scope_change?(node)
-          scope_changing_syntax?(node)          ||
+          scope_changing_syntax?(node) ||
             common_instance_exec_closure?(node) ||
             skippable_block?(node)
         end
 
         def skippable_block?(node)
-          node.block_type? && !rspec_block?(node) && skip_blocks?
-        end
-
-        def skip_blocks?
-          cop_config['SkipBlocks']
+          node.block_type? && !rspec_block?(node) && cop_config['SkipBlocks']
         end
 
         def offensive?(node)
           if style == :described_class
             offensive_described_class?(node)
           else
-            node.send_type? && node.method_name == :described_class
+            node.send_type? && node.method?(:described_class)
           end
         end
 
         def offensive_described_class?(node)
           return unless node.const_type?
+
           # E.g. `described_class::CONSTANT`
           return if contains_described_class?(node)
 
@@ -160,7 +161,8 @@ module RuboCop
         end
 
         def full_const_name(node)
-          collapse_namespace(namespace(node), const_name(node))
+          symbolized_namespace = namespace(node).map(&:to_sym)
+          collapse_namespace(symbolized_namespace, const_name(node))
         end
 
         # @param namespace [Array<Symbol>]
@@ -168,14 +170,13 @@ module RuboCop
         # @return [Array<Symbol>]
         # @example
         #   # nil represents base constant
-        #   collapse_namespace([], :C)                 # => [:C]
-        #   collapse_namespace([:A, :B], [:C)          # => [:A, :B, :C]
-        #   collapse_namespace([:A, :B], [:B, :C)      # => [:A, :B, :C]
-        #   collapse_namespace([:A, :B], [nil, :C)     # => [nil, :C]
-        #   collapse_namespace([:A, :B], [nil, :B, :C) # => [nil, :B, :C]
+        #   collapse_namespace([], [:C])                # => [:C]
+        #   collapse_namespace([:A, :B], [:C])          # => [:A, :B, :C]
+        #   collapse_namespace([:A, :B], [:B, :C])      # => [:A, :B, :C]
+        #   collapse_namespace([:A, :B], [nil, :C])     # => [nil, :C]
+        #   collapse_namespace([:A, :B], [nil, :B, :C]) # => [nil, :B, :C]
         def collapse_namespace(namespace, const)
-          return const if namespace.empty?
-          return const if const.first.nil?
+          return const if namespace.empty? || const.first.nil?
 
           start = [0, (namespace.length - const.length)].max
           max = namespace.length
@@ -192,29 +193,15 @@ module RuboCop
         #   const_name(s(:const, s(:const, nil, :M), :C)) # => [:M, :C]
         #   const_name(s(:const, s(:cbase), :C))          # => [nil, :C]
         def const_name(node)
-          # rubocop:disable InternalAffairs/NodeDestructuring
-          namespace, name = *node
-          # rubocop:enable InternalAffairs/NodeDestructuring
+          namespace, name = *node # rubocop:disable InternalAffairs/NodeDestructuring
           if !namespace
             [name]
           elsif namespace.const_type?
             [*const_name(namespace), name]
-          elsif namespace.lvar_type? || namespace.cbase_type?
+          elsif %i[lvar cbase send].include?(namespace.type)
             [nil, name]
           end
         end
-
-        # @param node [RuboCop::AST::Node]
-        # @return [Array<Symbol>]
-        # @example
-        #   namespace(node) # => [:A, :B, :C]
-        def namespace(node)
-          node
-            .each_ancestor(:class, :module)
-            .reverse_each
-            .flat_map { |ancestor| ancestor.defined_module_name.split('::') }
-            .map(&:to_sym)
-        end
       end
     end
   end
