@@ -18,12 +18,12 @@ module RuboCop
       #     # ...
       #   end
       #
-      # @see https://github.com/rubocop-hq/rubocop-rspec/issues/735
-      class DescribedClassModuleWrapping < Cop
+      # @see https://github.com/rubocop/rubocop-rspec/issues/735
+      class DescribedClassModuleWrapping < Base
         MSG = 'Avoid opening modules and defining specs within them.'
 
-        def_node_search :find_rspec_blocks,
-                        ExampleGroups::ALL.block_pattern
+        # @!method find_rspec_blocks(node)
+        def_node_search :find_rspec_blocks, block_pattern('#ExampleGroups.all')
 
         def on_module(node)
           find_rspec_blocks(node) do
