@@ -22,21 +22,24 @@ module RuboCop
       #     create_feed
       #   end
       #   after(:all) { cleanup_feed }
-      class EmptyHook < Cop
+      #
+      class EmptyHook < Base
         extend AutoCorrector
         include RuboCop::Cop::RangeHelp
 
         MSG = 'Empty hook detected.'
 
+        # @!method empty_hook?(node)
         def_node_matcher :empty_hook?, <<~PATTERN
-          (block $#{Hooks::ALL.send_pattern} _ nil?)
+          (block $#{send_pattern('#Hooks.all')} _ nil?)
         PATTERN
 
-        def on_block(node)
+        def on_block(node) # rubocop:disable InternalAffairs/NumblockHandler
           empty_hook?(node) do |hook|
             add_offense(hook) do |corrector|
-              range = range_with_surrounding_space(range: node.loc.expression)
-              corrector.remove(range)
+              corrector.remove(
+                range_with_surrounding_space(node.loc.expression, side: :left)
+              )
             end
           end
         end
