@@ -23,21 +23,17 @@ module RuboCop
       #     end
       #   end
       #
-      class EmptyLineAfterExampleGroup < Cop
+      class EmptyLineAfterExampleGroup < Base
         extend AutoCorrector
-        include RuboCop::RSpec::BlankLineSeparation
+        include EmptyLineSeparation
 
         MSG = 'Add an empty line after `%<example_group>s`.'
 
-        def on_block(node)
+        def on_block(node) # rubocop:disable InternalAffairs/NumblockHandler
           return unless example_group?(node)
-          return if last_child?(node)
 
-          missing_separating_line(node) do |location|
-            msg = format(MSG, example_group: node.method_name)
-            add_offense(location, message: msg) do |corrector|
-              corrector.insert_after(location.end, "\n")
-            end
+          missing_separating_line_offense(node) do |method|
+            format(MSG, example_group: method)
           end
         end
       end
