@@ -16,24 +16,22 @@ module RuboCop
       #   let(:something) { other }
       #
       #   it { does_something }
-      class EmptyLineAfterFinalLet < Cop
+      #
+      class EmptyLineAfterFinalLet < Base
         extend AutoCorrector
-        include RuboCop::RSpec::BlankLineSeparation
+        include EmptyLineSeparation
 
-        MSG = 'Add an empty line after the last `let` block.'
+        MSG = 'Add an empty line after the last `%<let>s`.'
 
-        def on_block(node)
+        def on_block(node) # rubocop:disable InternalAffairs/NumblockHandler
           return unless example_group_with_body?(node)
 
-          latest_let = node.body.child_nodes.select { |child| let?(child) }.last
+          final_let = node.body.child_nodes.reverse.find { |child| let?(child) }
 
-          return if latest_let.nil?
-          return if last_child?(latest_let)
+          return if final_let.nil?
 
-          missing_separating_line(latest_let) do |location|
-            add_offense(location) do |corrector|
-              corrector.insert_after(location.end, "\n")
-            end
+          missing_separating_line_offense(final_let) do |method|
+            format(MSG, let: method)
           end
         end
       end
