@@ -6,12 +6,17 @@ module RuboCop
       # Checks for common mistakes in example descriptions.
       #
       # This cop will correct docstrings that begin with 'should' and 'it'.
+      # This cop will also look for insufficient examples and call them out.
       #
       # @see http://betterspecs.org/#should
       #
       # The autocorrect is experimental - use with care! It can be configured
       # with CustomTransform (e.g. have => has) and IgnoredWords (e.g. only).
       #
+      # Use the DisallowedExamples setting to prevent unclear or insufficient
+      # descriptions. Please note that this config will not be treated as
+      # case sensitive.
+      #
       # @example
       #   # bad
       #   it 'should find nothing' do
@@ -29,15 +34,27 @@ module RuboCop
       #   # good
       #   it 'does things' do
       #   end
-      class ExampleWording < Cop
+      #
+      # @example `DisallowedExamples: ['works']` (default)
+      #   # bad
+      #   it 'works' do
+      #   end
+      #
+      #   # good
+      #   it 'marks the task as done' do
+      #   end
+      class ExampleWording < Base
         extend AutoCorrector
 
         MSG_SHOULD = 'Do not use should when describing your tests.'
         MSG_IT     = "Do not repeat 'it' when describing your tests."
+        MSG_INSUFFICIENT_DESCRIPTION = 'Your example description is ' \
+                                       'insufficient.'
 
         SHOULD_PREFIX = /\Ashould(?:n't)?\b/i.freeze
         IT_PREFIX     = /\Ait /i.freeze
 
+        # @!method it_description(node)
         def_node_matcher :it_description, <<-PATTERN
           (block (send _ :it ${
             (str $_)
@@ -45,12 +62,15 @@ module RuboCop
           } ...) ...)
         PATTERN
 
-        def on_block(node)
+        def on_block(node) # rubocop:disable InternalAffairs/NumblockHandler
           it_description(node) do |description_node, message|
-            if message =~ SHOULD_PREFIX
+            if message.match?(SHOULD_PREFIX)
               add_wording_offense(description_node, MSG_SHOULD)
-            elsif message =~ IT_PREFIX
+            elsif message.match?(IT_PREFIX)
               add_wording_offense(description_node, MSG_IT)
+            elsif insufficient_docstring?(description_node)
+              add_offense(docstring(description_node),
+                          message: MSG_INSUFFICIENT_DESCRIPTION)
             end
           end
         end
@@ -59,7 +79,10 @@ module RuboCop
 
         def add_wording_offense(node, message)
           docstring = docstring(node)
+
           add_offense(docstring, message: message) do |corrector|
+            next if node.heredoc?
+
             corrector.replace(docstring, replacement_text(node))
           end
         end
@@ -77,7 +100,7 @@ module RuboCop
         def replacement_text(node)
           text = text(node)
 
-          if text =~ SHOULD_PREFIX
+          if text.match?(SHOULD_PREFIX)
             RuboCop::RSpec::Wording.new(
               text,
               ignore:  ignored_words,
@@ -108,6 +131,19 @@ module RuboCop
         def ignored_words
           cop_config.fetch('IgnoredWords', [])
         end
+
+        def insufficient_docstring?(description_node)
+          insufficient_examples.include?(preprocess(text(description_node)))
+        end
+
+        def insufficient_examples
+          examples = cop_config.fetch('DisallowedExamples', [])
+          examples.map! { |example| preprocess(example) }
+        end
+
+        def preprocess(message)
+          message.strip.squeeze(' ').downcase
+        end
       end
     end
   end
