@@ -5,6 +5,8 @@ module RuboCop
     module RSpec
       # Checks for `expect(...)` calls containing literal values.
       #
+      # Autocorrection is performed when the expected is not a literal.
+      #
       # @example
       #   # bad
       #   expect(5).to eq(price)
@@ -16,11 +18,16 @@ module RuboCop
       #   expect(pattern).to eq(/foo/)
       #   expect(name).to eq("John")
       #
-      class ExpectActual < Cop
+      #   # bad (not supported autocorrection)
+      #   expect(false).to eq(true)
+      #
+      class ExpectActual < Base
         extend AutoCorrector
 
         MSG = 'Provide the actual you are testing to `expect(...)`.'
 
+        RESTRICT_ON_SEND = Runners.all
+
         SIMPLE_LITERALS = %i[
           true
           false
@@ -45,10 +52,11 @@ module RuboCop
 
         SUPPORTED_MATCHERS = %i[eq eql equal be].freeze
 
+        # @!method expect_literal(node)
         def_node_matcher :expect_literal, <<~PATTERN
           (send
             (send nil? :expect $#literal?)
-            #{Runners::ALL.node_pattern_union}
+            #Runners.all
             {
               (send (send nil? $:be) :== $_)
               (send nil? $_ $_ ...)
@@ -60,6 +68,7 @@ module RuboCop
           expect_literal(node) do |actual, matcher, expected|
             add_offense(actual.source_range) do |corrector|
               next unless SUPPORTED_MATCHERS.include?(matcher)
+              next if literal?(expected)
 
               swap(corrector, actual, expected)
             end
