@@ -10,14 +10,7 @@ module RuboCop
       #
       # This cop can be configured using the `EnforcedStyle` option.
       #
-      # @example `EnforcedStyle: block`
-      #   # bad
-      #   expect { run }.to change(Foo, :bar)
-      #
-      #   # good
-      #   expect { run }.to change { Foo.bar }
-      #
-      # @example `EnforcedStyle: method_call`
+      # @example `EnforcedStyle: method_call` (default)
       #   # bad
       #   expect { run }.to change { Foo.bar }
       #   expect { run }.to change { foo.baz }
@@ -29,22 +22,38 @@ module RuboCop
       #   expect { run }.to change { Foo.bar(:count) }
       #   expect { run }.to change { user.reload.name }
       #
-      class ExpectChange < Cop
+      # @example `EnforcedStyle: block`
+      #   # bad
+      #   expect { run }.to change(Foo, :bar)
+      #
+      #   # good
+      #   expect { run }.to change { Foo.bar }
+      #
+      class ExpectChange < Base
         extend AutoCorrector
         include ConfigurableEnforcedStyle
 
         MSG_BLOCK = 'Prefer `change(%<obj>s, :%<attr>s)`.'
         MSG_CALL = 'Prefer `change { %<obj>s.%<attr>s }`.'
+        RESTRICT_ON_SEND = %i[change].freeze
 
+        # @!method expect_change_with_arguments(node)
         def_node_matcher :expect_change_with_arguments, <<-PATTERN
-          (send nil? :change ({const send} nil? $_) (sym $_))
+          (send nil? :change $_ ({sym str} $_))
         PATTERN
 
+        # @!method expect_change_with_block(node)
         def_node_matcher :expect_change_with_block, <<-PATTERN
           (block
             (send nil? :change)
             (args)
-            (send ({const send} nil? $_) $_)
+            (send
+              ${
+                (send nil? _)  # change { user.name }
+                const          # change { User.count }
+              }
+              $_
+            )
           )
         PATTERN
 
@@ -52,21 +61,21 @@ module RuboCop
           return unless style == :block
 
           expect_change_with_arguments(node) do |receiver, message|
-            msg = format(MSG_CALL, obj: receiver, attr: message)
+            msg = format(MSG_CALL, obj: receiver.source, attr: message)
             add_offense(node, message: msg) do |corrector|
-              replacement = "change { #{receiver}.#{message} }"
+              replacement = "change { #{receiver.source}.#{message} }"
               corrector.replace(node, replacement)
             end
           end
         end
 
-        def on_block(node)
+        def on_block(node) # rubocop:disable InternalAffairs/NumblockHandler
           return unless style == :method_call
 
           expect_change_with_block(node) do |receiver, message|
-            msg = format(MSG_BLOCK, obj: receiver, attr: message)
+            msg = format(MSG_BLOCK, obj: receiver.source, attr: message)
             add_offense(node, message: msg) do |corrector|
-              replacement = "change(#{receiver}, :#{message})"
+              replacement = "change(#{receiver.source}, :#{message})"
               corrector.replace(node, replacement)
             end
           end
