@@ -8,8 +8,7 @@ module RuboCop
       # This cop can be configured using the `EnforcedStyle` option
       # and supports the `--auto-gen-config` flag.
       #
-      # @example `EnforcedStyle: is_expected`
-      #
+      # @example `EnforcedStyle: is_expected` (default)
       #   # bad
       #   it { should be_truthy }
       #
@@ -17,23 +16,25 @@ module RuboCop
       #   it { is_expected.to be_truthy }
       #
       # @example `EnforcedStyle: should`
-      #
       #   # bad
       #   it { is_expected.to be_truthy }
       #
       #   # good
       #   it { should be_truthy }
       #
-      class ImplicitExpect < Cop
+      class ImplicitExpect < Base
         extend AutoCorrector
         include ConfigurableEnforcedStyle
 
         MSG = 'Prefer `%<good>s` over `%<bad>s`.'
 
+        RESTRICT_ON_SEND = Runners.all + %i[should should_not]
+
+        # @!method implicit_expect(node)
         def_node_matcher :implicit_expect, <<-PATTERN
           {
             (send nil? ${:should :should_not} ...)
-            (send (send nil? $:is_expected) #{Runners::ALL.node_pattern_union} ...)
+            (send (send nil? $:is_expected) #Runners.all ...)
           }
         PATTERN
 
