@@ -5,26 +5,29 @@ module RuboCop
     module RSpec
       # Checks that only one `it_behaves_like` style is used.
       #
-      # @example when configuration is `EnforcedStyle: it_behaves_like`
+      # @example `EnforcedStyle: it_behaves_like` (default)
       #   # bad
       #   it_should_behave_like 'a foo'
       #
       #   # good
       #   it_behaves_like 'a foo'
       #
-      # @example when configuration is `EnforcedStyle: it_should_behave_like`
+      # @example `EnforcedStyle: it_should_behave_like`
       #   # bad
       #   it_behaves_like 'a foo'
       #
       #   # good
       #   it_should_behave_like 'a foo'
-      class ItBehavesLike < Cop
+      #
+      class ItBehavesLike < Base
         extend AutoCorrector
         include ConfigurableEnforcedStyle
 
-        MSG = 'Prefer `%<replacement>s` over `%<original>s` when including '\
+        MSG = 'Prefer `%<replacement>s` over `%<original>s` when including ' \
               'examples in a nested context.'
+        RESTRICT_ON_SEND = %i[it_behaves_like it_should_behave_like].freeze
 
+        # @!method example_inclusion_offense(node)
         def_node_matcher :example_inclusion_offense, '(send _ % ...)'
 
         def on_send(node)
