@@ -6,7 +6,7 @@ module RuboCop
       # Checks for `let` definitions that come after an example.
       #
       # @example
-      #   # Bad
+      #   # bad
       #   let(:foo) { bar }
       #
       #   it 'checks what foo does' do
@@ -19,7 +19,7 @@ module RuboCop
       #     expect(some).to be
       #   end
       #
-      #   # Good
+      #   # good
       #   let(:foo) { bar }
       #   let(:some) { other }
       #
@@ -30,19 +30,28 @@ module RuboCop
       #   it 'checks what some does' do
       #     expect(some).to be
       #   end
-      class LetBeforeExamples < Cop
+      class LetBeforeExamples < Base
         extend AutoCorrector
 
         MSG = 'Move `let` before the examples in the group.'
 
+        # @!method example_or_group?(node)
         def_node_matcher :example_or_group?, <<-PATTERN
           {
-            #{(Examples::ALL + ExampleGroups::ALL).block_pattern}
-            #{Includes::EXAMPLES.send_pattern}
+            #{block_pattern('{#ExampleGroups.all #Examples.all}')}
+            #{send_pattern('#Includes.examples')}
           }
         PATTERN
 
-        def on_block(node)
+        # @!method include_examples?(node)
+        def_node_matcher :include_examples?, <<~PATTERN
+          {
+            #{block_pattern(':include_examples')}
+            #{send_pattern(':include_examples')}
+          }
+        PATTERN
+
+        def on_block(node) # rubocop:disable InternalAffairs/NumblockHandler
           return unless example_group_with_body?(node)
 
           check_let_declarations(node.body) if multiline_block?(node.body)
@@ -50,6 +59,10 @@ module RuboCop
 
         private
 
+        def example_group_with_include_examples?(body)
+          body.children.any? { |sibling| include_examples?(sibling) }
+        end
+
         def multiline_block?(block)
           block.begin_type?
         end
@@ -58,12 +71,13 @@ module RuboCop
           first_example = find_first_example(node)
           return unless first_example
 
-          node.each_child_node do |child|
-            next if child.sibling_index < first_example.sibling_index
-            next unless let?(child)
+          correct = !example_group_with_include_examples?(node)
 
-            add_offense(child) do |corrector|
-              autocorrect(corrector, child, first_example)
+          first_example.right_siblings.each do |sibling|
+            next unless let?(sibling)
+
+            add_offense(sibling) do |corrector|
+              autocorrect(corrector, sibling, first_example) if correct
             end
           end
         end
