@@ -8,37 +8,47 @@ module RuboCop
       # This cop can be configured in your configuration using the
       # `EnforcedStyle` option and supports `--auto-gen-config`.
       #
-      # @example `EnforcedStyle: have_received`
+      # @example `EnforcedStyle: have_received` (default)
       #
       #   # bad
       #   expect(foo).to receive(:bar)
+      #   do_something
       #
       #   # good
+      #   allow(foo).to receive(:bar) # or use instance_spy
+      #   do_something
       #   expect(foo).to have_received(:bar)
       #
       # @example `EnforcedStyle: receive`
       #
       #   # bad
+      #   allow(foo).to receive(:bar)
+      #   do_something
       #   expect(foo).to have_received(:bar)
       #
       #   # good
       #   expect(foo).to receive(:bar)
+      #   do_something
       #
-      class MessageSpies < Cop
+      class MessageSpies < Base
         include ConfigurableEnforcedStyle
 
         MSG_RECEIVE = 'Prefer `receive` for setting message expectations.'
 
-        MSG_HAVE_RECEIVED = 'Prefer `have_received` for setting message '\
-                            'expectations. Setup `%<source>s` as a spy using '\
+        MSG_HAVE_RECEIVED = 'Prefer `have_received` for setting message ' \
+                            'expectations. Setup `%<source>s` as a spy using ' \
                             '`allow` or `instance_spy`.'
 
         SUPPORTED_STYLES = %w[have_received receive].freeze
 
+        RESTRICT_ON_SEND = Runners.all
+
+        # @!method message_expectation(node)
         def_node_matcher :message_expectation, %(
-          (send (send nil? :expect $_) #{Runners::ALL.node_pattern_union} ...)
+          (send (send nil? :expect $_) #Runners.all ...)
         )
 
+        # @!method receive_message(node)
         def_node_search :receive_message, %(
           $(send nil? {:receive :have_received} ...)
         )
