@@ -6,7 +6,7 @@ module RuboCop
       # Checks for nested example groups.
       #
       # This cop is configurable using the `Max` option
-      # and supports `--auto-gen-config
+      # and supports `--auto-gen-config`.
       #
       # @example
       #   # bad
@@ -36,7 +36,7 @@ module RuboCop
       #     end
       #   end
       #
-      #   # better
+      #   # good
       #   context 'using some feature as an admin' do
       #     let(:some)    { :various }
       #     let(:feature) { :setup   }
@@ -53,41 +53,47 @@ module RuboCop
       #     it 'yada yada'
       #   end
       #
-      # @example configuration
-      #
-      #   # .rubocop.yml
-      #   # RSpec/NestedGroups:
-      #   #   Max: 2
-      #
-      #   context 'when using some feature' do
-      #     let(:some)    { :various }
-      #     let(:feature) { :setup   }
-      #
-      #     context 'when user is signed in' do
-      #       let(:user) do
-      #         UserCreate.call(user_attributes)
-      #       end
-      #
-      #       let(:user_attributes) do
-      #         {
-      #           name: 'John',
-      #           age:  22,
-      #           role: role
-      #         }
-      #       end
-      #
-      #       context 'when user is an admin' do # flagged by rubocop
-      #         let(:role) { 'admin' }
-      #
-      #         it 'blah blah'
-      #         it 'yada yada'
+      # @example `Max: 3` (default)
+      #   # bad
+      #   describe Foo do
+      #     context 'foo' do
+      #       context 'bar' do
+      #         context 'baz' do # flagged by rubocop
+      #         end
       #       end
       #     end
       #   end
       #
-      class NestedGroups < Cop
+      # @example `Max: 2`
+      #   # bad
+      #   describe Foo do
+      #     context 'foo' do
+      #       context 'bar' do # flagged by rubocop
+      #         context 'baz' do # flagged by rubocop
+      #         end
+      #       end
+      #     end
+      #   end
+      #
+      # @example `AllowedGroups: [] (default)`
+      #   describe Foo do # <-- nested groups 1
+      #     context 'foo' do # <-- nested groups 2
+      #       context 'bar' do # <-- nested groups 3
+      #       end
+      #     end
+      #   end
+      #
+      # @example `AllowedGroups: [path]`
+      #   describe Foo do # <-- nested groups 1
+      #     path '/foo' do # <-- nested groups 1 (not counted)
+      #       context 'bar' do # <-- nested groups 2
+      #       end
+      #     end
+      #   end
+      #
+      class NestedGroups < Base
         include ConfigurableMax
-        include RuboCop::RSpec::TopLevelDescribe
+        include TopLevelGroup
 
         MSG = 'Maximum example group nesting exceeded [%<total>d/%<max>d].'
 
@@ -97,8 +103,8 @@ module RuboCop
           "Configuration key `#{DEPRECATED_MAX_KEY}` for #{cop_name} is " \
           'deprecated in favor of `Max`. Please use that instead.'
 
-        def on_top_level_describe(node, _args)
-          find_nested_example_groups(node.parent) do |example_group, nesting|
+        def on_top_level_group(node)
+          find_nested_example_groups(node) do |example_group, nesting|
             self.max = nesting
             add_offense(
               example_group.send_node,
@@ -113,13 +119,23 @@ module RuboCop
           example_group = example_group?(node)
           yield node, nesting if example_group && nesting > max_nesting
 
-          next_nesting = example_group ? nesting + 1 : nesting
+          next_nesting = if count_up_nesting?(node, example_group)
+                           nesting + 1
+                         else
+                           nesting
+                         end
 
           node.each_child_node(:block, :begin) do |child|
             find_nested_example_groups(child, nesting: next_nesting, &block)
           end
         end
 
+        def count_up_nesting?(node, example_group)
+          example_group &&
+            (node.block_type? &&
+            !allowed_groups.include?(node.method_name.to_s))
+        end
+
         def message(nesting)
           format(MSG, total: nesting, max: max_nesting)
         end
@@ -136,6 +152,10 @@ module RuboCop
             cop_config.fetch('Max', 3)
           end
         end
+
+        def allowed_groups
+          @allowed_groups ||= cop_config.fetch('AllowedGroups', [])
+        end
       end
     end
   end
