@@ -25,19 +25,22 @@ module RuboCop
           end
         end
 
+        # @!method predicate_in_actual?(node)
         def_node_matcher :predicate_in_actual?, <<-PATTERN
           (send
             (send nil? :expect {
               (block $(send !nil? #predicate? ...) ...)
               $(send !nil? #predicate? ...)})
-            $#{Runners::ALL.node_pattern_union}
+            $#Runners.all
             $#boolean_matcher?)
         PATTERN
 
+        # @!method be_bool?(node)
         def_node_matcher :be_bool?, <<-PATTERN
           (send nil? {:be :eq :eql :equal} {true false})
         PATTERN
 
+        # @!method be_boolthy?(node)
         def_node_matcher :be_boolthy?, <<-PATTERN
           (send nil? {:be_truthy :be_falsey :be_falsy :a_truthy_value :a_falsey_value :a_falsy_value})
         PATTERN
@@ -152,19 +155,21 @@ module RuboCop
           end
         end
 
+        # @!method predicate_matcher?(node)
         def_node_matcher :predicate_matcher?, <<-PATTERN
           (send
             (send nil? :expect $!nil?)
-            #{Runners::ALL.node_pattern_union}
+            #Runners.all
             {$(send nil? #predicate_matcher_name? ...)
               (block $(send nil? #predicate_matcher_name? ...) ...)})
         PATTERN
 
+        # @!method predicate_matcher_block?(node)
         def_node_matcher :predicate_matcher_block?, <<-PATTERN
           (block
             (send
               (send nil? :expect $!nil?)
-              #{Runners::ALL.node_pattern_union}
+              #Runners.all
               $(send nil? #predicate_matcher_name?))
             ...)
         PATTERN
@@ -208,18 +213,20 @@ module RuboCop
             'is_a?'
           when 'be_an_instance_of', 'be_instance_of', 'an_instance_of'
             'instance_of?'
-          when 'include', 'respond_to'
-            matcher + '?'
+          when 'include'
+            'include?'
+          when 'respond_to'
+            'respond_to?'
           when /^have_(.+)/
             "has_#{Regexp.last_match(1)}?"
           else
-            matcher[/^be_(.+)/, 1] + '?'
+            "#{matcher[/^be_(.+)/, 1]}?"
           end
         end
         # rubocop:enable Metrics/MethodLength
 
         def replacement_matcher(node)
-          case [cop_config['Strict'], node.method_name == :to]
+          case [cop_config['Strict'], node.method?(:to)]
           when [true, true]
             'be(true)'
           when [true, false]
@@ -269,12 +276,15 @@ module RuboCop
       #
       #   # good - the above code is rewritten to it by this cop
       #   expect(foo.something?).to be_truthy
-      class PredicateMatcher < Cop
+      #
+      class PredicateMatcher < Base
         extend AutoCorrector
         include ConfigurableEnforcedStyle
         include InflectedHelper
         include ExplicitHelper
 
+        RESTRICT_ON_SEND = Runners.all
+
         def on_send(node)
           case style
           when :inflected
@@ -284,19 +294,10 @@ module RuboCop
           end
         end
 
-        def on_block(node)
+        def on_block(node) # rubocop:disable InternalAffairs/NumblockHandler
           check_explicit(node) if style == :explicit
         end
 
-        def autocorrect(node)
-          case style
-          when :inflected
-            autocorrect_inflected(node)
-          when :explicit
-            autocorrect_explicit(node)
-          end
-        end
-
         private
 
         # returns args location with whitespace
