@@ -6,21 +6,22 @@ module RuboCop
       # Prefer `not_to receive(...)` over `receive(...).never`.
       #
       # @example
+      #   # bad
+      #   expect(foo).to receive(:bar).never
       #
-      #     # bad
-      #     expect(foo).to receive(:bar).never
+      #   # good
+      #   expect(foo).not_to receive(:bar)
       #
-      #     # good
-      #     expect(foo).not_to receive(:bar)
-      #
-      class ReceiveNever < Cop
+      class ReceiveNever < Base
         extend AutoCorrector
         MSG = 'Use `not_to receive` instead of `never`.'
+        RESTRICT_ON_SEND = %i[never].freeze
 
+        # @!method method_on_stub?(node)
         def_node_search :method_on_stub?, '(send nil? :receive ...)'
 
         def on_send(node)
-          return unless node.method_name == :never && method_on_stub?(node)
+          return unless node.method?(:never) && method_on_stub?(node)
 
           add_offense(node.loc.selector) do |corrector|
             autocorrect(corrector, node)
