@@ -16,16 +16,19 @@ module RuboCop
       #   allow(foo).to receive(:bar, :baz)
       #   allow(foo).to receive("bar.baz")
       #
-      class SingleArgumentMessageChain < Cop
+      class SingleArgumentMessageChain < Base
         extend AutoCorrector
 
-        MSG = 'Use `%<recommended>s` instead of calling '\
+        MSG = 'Use `%<recommended>s` instead of calling ' \
               '`%<called>s` with a single argument.'
+        RESTRICT_ON_SEND = %i[receive_message_chain stub_chain].freeze
 
+        # @!method message_chain(node)
         def_node_matcher :message_chain, <<-PATTERN
           (send _ {:receive_message_chain :stub_chain} $_)
         PATTERN
 
+        # @!method single_key_hash?(node)
         def_node_matcher :single_key_hash?, '(hash pair)'
 
         def on_send(node)
