@@ -7,46 +7,81 @@ module RuboCop
     module RSpec
       # Checks for stubbed test subjects.
       #
+      # Checks nested subject stubs for innermost subject definition
+      # when subject is also defined in parent example groups.
+      #
       # @see https://robots.thoughtbot.com/don-t-stub-the-system-under-test
-      # @see https://samphippen.com/introducing-rspec-smells-and-where-to-find-them#smell-1-stubject
+      # @see https://penelope.zone/2015/12/27/introducing-rspec-smells-and-where-to-find-them.html#smell-1-stubjec
       # @see https://github.com/rubocop-hq/rspec-style-guide#dont-stub-subject
       #
       # @example
       #   # bad
-      #   describe Foo do
-      #     subject(:bar) { baz }
+      #   describe Article do
+      #     subject(:article) { Article.new }
       #
-      #     before do
-      #       allow(bar).to receive(:qux?).and_return(true)
+      #     it 'indicates that the author is unknown' do
+      #       allow(article).to receive(:author).and_return(nil)
+      #       expect(article.description).to include('by an unknown author')
       #     end
       #   end
       #
-      class SubjectStub < Cop
-        include RuboCop::RSpec::TopLevelGroup
+      #   # bad
+      #   describe Article do
+      #     subject(:foo) { Article.new }
+      #
+      #     context 'nested subject' do
+      #       subject(:article) { Article.new }
+      #
+      #       it 'indicates that the author is unknown' do
+      #         allow(article).to receive(:author).and_return(nil)
+      #         expect(article.description).to include('by an unknown author')
+      #       end
+      #     end
+      #   end
+      #
+      #   # good
+      #   describe Article do
+      #     subject(:article) { Article.new(author: nil) }
+      #
+      #     it 'indicates that the author is unknown' do
+      #       expect(article.description).to include('by an unknown author')
+      #     end
+      #   end
+      #
+      class SubjectStub < Base
+        include TopLevelGroup
 
         MSG = 'Do not stub methods of the object under test.'
 
-        # @!method subject(node)
+        # @!method subject?(node)
         #   Find a named or unnamed subject definition
         #
         #   @example anonymous subject
-        #     subject(parse('subject { foo }').ast) do |name|
+        #     subject?(parse('subject { foo }').ast) do |name|
         #       name # => :subject
         #     end
         #
         #   @example named subject
-        #     subject(parse('subject(:thing) { foo }').ast) do |name|
+        #     subject?(parse('subject(:thing) { foo }').ast) do |name|
         #       name # => :thing
         #     end
         #
-        #   @param node [RuboCop::Node]
+        #   @param node [RuboCop::AST::Node]
         #
         #   @yield [Symbol] subject name
-        def_node_matcher :subject, <<-PATTERN
-          {
-            (block (send nil? :subject (sym $_)) args ...)
-            (block (send nil? $:subject) args ...)
-          }
+        def_node_matcher :subject?, <<-PATTERN
+          (block
+            (send nil?
+              { #Subjects.all (sym $_) | $#Subjects.all }
+            ) args ...)
+        PATTERN
+
+        # @!method let?(node)
+        #   Find a memoized helper
+        def_node_matcher :let?, <<-PATTERN
+          (block
+            (send nil? :let (sym $_)
+            ) args ...)
         PATTERN
 
         # @!method message_expectation?(node, method_name)
@@ -63,14 +98,15 @@ module RuboCop
         def_node_matcher :message_expectation?, <<-PATTERN
           (send
             {
-              (send nil? { :expect :allow } (send nil? {% :subject}))
+              (send nil? { :expect :allow } (send nil? %))
               (send nil? :is_expected)
             }
-            #{Runners::ALL.node_pattern_union}
+            #Runners.all
             #message_expectation_matcher?
           )
         PATTERN
 
+        # @!method message_expectation_matcher?(node)
         def_node_search :message_expectation_matcher?, <<-PATTERN
           (send nil? {
             :receive :receive_messages :receive_message_chain :have_received
@@ -78,7 +114,8 @@ module RuboCop
         PATTERN
 
         def on_top_level_group(node)
-          @explicit_subjects = find_all_explicit_subjects(node)
+          @explicit_subjects = find_all_explicit(node, &method(:subject?))
+          @subject_overrides = find_all_explicit(node, &method(:let?))
 
           find_subject_expectations(node) do |stub|
             add_offense(stub)
@@ -87,12 +124,12 @@ module RuboCop
 
         private
 
-        def find_all_explicit_subjects(node)
+        def find_all_explicit(node)
           node.each_descendant(:block).with_object({}) do |child, h|
-            name = subject(child)
+            name = yield(child)
             next unless name
 
-            outer_example_group = child.each_ancestor.find do |a|
+            outer_example_group = child.each_ancestor(:block).find do |a|
               example_group?(a)
             end
 
@@ -102,14 +139,14 @@ module RuboCop
         end
 
         def find_subject_expectations(node, subject_names = [], &block)
-          subject_names = @explicit_subjects[node] if @explicit_subjects[node]
+          subject_names = [*subject_names, *@explicit_subjects[node]]
+          subject_names -= @subject_overrides[node] if @subject_overrides[node]
 
-          expectation_detected = (subject_names + [:subject]).any? do |name|
-            message_expectation?(node, name)
-          end
+          names = Set[*subject_names, :subject]
+          expectation_detected = message_expectation?(node, names)
           return yield(node) if expectation_detected
 
-          node.each_child_node do |child|
+          node.each_child_node(:send, :def, :block, :begin) do |child|
             find_subject_expectations(child, subject_names, &block)
           end
         end
