@@ -22,9 +22,12 @@ module RuboCop
       #   let(:foo) do
       #     instance_double("ClassName", method_name: 'returned value')
       #   end
-      class VerifiedDoubles < Cop
+      #
+      class VerifiedDoubles < Base
         MSG = 'Prefer using verifying doubles over normal doubles.'
+        RESTRICT_ON_SEND = %i[double spy].freeze
 
+        # @!method unverified_double(node)
         def_node_matcher :unverified_double, <<-PATTERN
           {(send nil? {:double :spy} $...)}
         PATTERN
