@@ -3,7 +3,7 @@
 module RuboCop
   module Cop
     module RSpec
-      # This cop checks void `expect()`.
+      # Checks void `expect()`.
       #
       # @example
       #   # bad
@@ -11,14 +11,18 @@ module RuboCop
       #
       #   # good
       #   expect(something).to be(1)
-      class VoidExpect < Cop
+      #
+      class VoidExpect < Base
         MSG = 'Do not use `expect()` without `.to` or `.not_to`. ' \
               'Chain the methods or remove it.'
+        RESTRICT_ON_SEND = %i[expect].freeze
 
+        # @!method expect?(node)
         def_node_matcher :expect?, <<-PATTERN
           (send nil? :expect ...)
         PATTERN
 
+        # @!method expect_block?(node)
         def_node_matcher :expect_block?, <<-PATTERN
           (block #expect? (args) _body)
         PATTERN
@@ -29,7 +33,7 @@ module RuboCop
           check_expect(node)
         end
 
-        def on_block(node)
+        def on_block(node) # rubocop:disable InternalAffairs/NumblockHandler
           return unless expect_block?(node)
 
           check_expect(node)
