@@ -6,7 +6,8 @@ module RuboCop
       # Helper methods to move a node
       class MoveNode
         include RuboCop::Cop::RangeHelp
-        include RuboCop::RSpec::FinalEndLocation
+        include RuboCop::Cop::RSpec::CommentsHelp
+        include RuboCop::Cop::RSpec::FinalEndLocation
 
         attr_reader :original, :corrector, :processed_source
 
@@ -16,19 +17,17 @@ module RuboCop
           @processed_source = processed_source # used by RangeHelp
         end
 
-        def move_before(other) # rubocop:disable Metrics/AbcSize
-          position = other.loc.expression
-          indent = "\n" + ' ' * other.loc.column
+        def move_before(other)
+          position = start_line_position(other)
 
-          corrector.insert_before(position, source(original) + indent)
+          corrector.insert_before(position, "#{source(original)}\n")
           corrector.remove(node_range_with_surrounding_space(original))
         end
 
         def move_after(other)
-          position = final_end_location(other)
-          indent = "\n" + ' ' * other.loc.column
+          position = end_line_position(other)
 
-          corrector.insert_after(position, indent + source(original))
+          corrector.insert_after(position, "\n#{source(original)}")
           corrector.remove(node_range_with_surrounding_space(original))
         end
 
@@ -39,7 +38,7 @@ module RuboCop
         end
 
         def node_range(node)
-          node.loc.expression.with(end_pos: final_end_location(node).end_pos)
+          source_range_with_comment(node)
         end
 
         def node_range_with_surrounding_space(node)
