@@ -21,7 +21,8 @@ module RuboCop
 
       # Decorator of a YARD code object for working with documented rspec cops
       class CodeObject
-        COP_CLASS_NAME = 'RuboCop::Cop::RSpec::Cop'
+        RSPEC_COP_CLASS_NAME = 'RuboCop::Cop::RSpec::Base'
+        RUBOCOP_COP_CLASS_NAME = 'RuboCop::Cop::Base'
         RSPEC_NAMESPACE = 'RuboCop::Cop::RSpec'
 
         def initialize(yardoc)
@@ -32,10 +33,7 @@ module RuboCop
         #
         # @return [Boolean]
         def rspec_cop?
-          class_documentation? &&
-            rspec_cop_namespace? &&
-            cop_subclass? &&
-            !abstract?
+          cop_subclass? && !abstract? && rspec_cop_namespace?
         end
 
         # Configuration for the documented cop that would live in default.yml
@@ -55,10 +53,6 @@ module RuboCop
           yardoc.docstring.split("\n\n").first.to_s
         end
 
-        def class_documentation?
-          yardoc.type.equal?(:class)
-        end
-
         def rspec_cop_namespace?
           documented_constant.start_with?(RSPEC_NAMESPACE)
         end
@@ -68,7 +62,8 @@ module RuboCop
         end
 
         def cop_subclass?
-          yardoc.superclass.path == COP_CLASS_NAME
+          yardoc.superclass.path == RSPEC_COP_CLASS_NAME ||
+            yardoc.superclass.path == RUBOCOP_COP_CLASS_NAME
         end
 
         def abstract?
