@@ -4,9 +4,29 @@ RSpec.describe 'CHANGELOG.md' do
   subject(:changelog) { SpecHelper::ROOT.join('CHANGELOG.md').read }
 
   it 'has link definitions for all implicit links' do
-    implicit_link_names = changelog.scan(/\[([^\]]+)\]\[\]/).flatten.uniq
-    implicit_link_names.each do |name|
-      expect(changelog).to include("[#{name}]: http")
+    entries, contributors =
+      changelog.split("<!-- Contributors (alphabetically) -->\n\n")
+
+    implicit_link_names = entries.scan(/\[@(.+?)\]/).flatten.uniq
+    expected_links = implicit_link_names.sort_by(&:downcase).map do |name|
+      "[@#{name.downcase}]: https://github.com/#{name}\n"
+    end.join
+
+    expect(contributors).to eq(expected_links)
+  end
+
+  describe 'contributors list' do
+    let(:contributors) do
+      changelog.split("<!-- Contributors (alphabetically) -->\n\n").last
+        .lines
+    end
+
+    it 'does not contain duplicates' do
+      expect(contributors.uniq).to eq(contributors)
+    end
+
+    it 'is alphabetically sorted (case insensitive)' do
+      expect(contributors.sort_by(&:downcase)).to eq(contributors)
     end
   end
 
@@ -26,7 +46,7 @@ RSpec.describe 'CHANGELOG.md' do
     describe 'link to related issue on github' do
       let(:issues) do
         entries.map do |entry|
-          entry.match(/\[(?<number>[#\d]+)\]\((?<url>[^\)]+)\)/)
+          entry.match(/\[(?<number>[#\d]+)\]\((?<url>[^)]+)\)/)
         end.compact
       end
 
@@ -58,7 +78,7 @@ RSpec.describe 'CHANGELOG.md' do
         entries.map do |entry|
           entry
             .sub(/^\*\s*(?:\[.+?\):\s*)?/, '')
-            .sub(/\s*\([^\)]+\)$/, '')
+            .sub(/\s*\([^)]+\)$/, '')
         end
       end
 
@@ -69,7 +89,7 @@ RSpec.describe 'CHANGELOG.md' do
       end
 
       it 'ends with a punctuation' do
-        expect(bodies).to all(match(/[\.\!]$/))
+        expect(bodies).to all(match(/[.!]$/))
       end
     end
   end
