@@ -8,9 +8,9 @@ RSpec.describe 'config/default.yml' do
   let(:namespaces) do
     {
       'rspec' => 'RSpec',
-      'capybara' => 'Capybara',
-      'factory_bot' => 'FactoryBot',
-      'rails' => 'Rails'
+      'capybara' => 'RSpec/Capybara',
+      'factory_bot' => 'RSpec/FactoryBot',
+      'rails' => 'RSpec/Rails'
     }
   end
 
@@ -25,11 +25,11 @@ RSpec.describe 'config/default.yml' do
         "#{namespace}/#{cop_name}"
       end
 
-    cop_names - %w[RSpec/Cop]
+    cop_names - %w[RSpec/Base]
   end
 
   let(:config_keys) do
-    cop_names + %w[AllCops]
+    cop_names + namespaces.values
   end
 
   def cop_configuration(config_key)
@@ -42,17 +42,24 @@ RSpec.describe 'config/default.yml' do
     end
   end
 
-  it 'has configuration for all cops' do
-    expect(default_config.keys).to match_array(config_keys)
+  it 'has configuration for all cops and amendments' do
+    expect(default_config.keys)
+      .to match_array([*config_keys, 'Metrics/BlockLength'])
   end
 
-  it 'sorts configuration keys alphabetically' do
-    namespaces.each do |_path, prefix|
-      expected = config_keys.select { |key| key.start_with?(prefix) }.sort
-      actual = default_config.keys.select { |key| key.start_with?(prefix) }
-      actual.each_with_index do |key, idx|
-        expect(key).to eq expected[idx]
-      end
+  it 'sorts configuration keys alphabetically with nested namespaces last' do
+    rspec_keys = default_config.keys.select { |key| key.start_with?('RSpec') }
+    namespaced_rspec_keys = rspec_keys.select do |key|
+      key.start_with?(*(namespaces.values - ['RSpec']))
+    end
+
+    expected = rspec_keys.sort_by do |key|
+      namespaced = namespaced_rspec_keys.include?(key) ? 1 : 0
+      "#{namespaced} #{key}"
+    end
+
+    rspec_keys.each_with_index do |key, idx|
+      expect(key).to eq expected[idx]
     end
   end
 
@@ -70,7 +77,8 @@ RSpec.describe 'config/default.yml' do
     expect(cop_configuration('Description')).to all(end_with('.'))
   end
 
-  it 'includes Enabled: true for every cop' do
-    expect(cop_configuration('Enabled')).to all(be(true).or(be(false)))
+  it 'includes a valid Enabled for every cop' do
+    expect(cop_configuration('Enabled'))
+      .to all be(true).or(be(false)).or(eq('pending'))
   end
 end
