@@ -1,8 +1,6 @@
 # frozen_string_literal: true
 
 RSpec.describe RuboCop::Cop::RSpec::AlignLeftLetBrace do
-  subject(:cop) { described_class.new }
-
   # rubocop:disable RSpec/ExampleLength
   it 'registers offense for unaligned braces' do
     expect_offense(<<-RUBY)
@@ -45,13 +43,13 @@ RSpec.describe RuboCop::Cop::RSpec::AlignLeftLetBrace do
   end
   # rubocop:enable RSpec/ExampleLength
 
-  it 'does not register offense for let with proc argument' do
+  it 'does not register an offense for let with proc argument' do
     expect_no_offenses(<<-RUBY)
       let(:user, &args[:build_user])
     RUBY
   end
 
-  it 'works with empty file' do
+  it 'does not register an offense with empty file' do
     expect_no_offenses('')
   end
 end
