@@ -1,13 +1,11 @@
 # frozen_string_literal: true
 
 RSpec.describe RuboCop::Cop::RSpec::BeforeAfterAll do
-  subject(:cop) { described_class.new }
-
   def message(hook)
-    "Beware of using `#{hook}` as it may cause state to leak between tests. "\
-    'If you are using `rspec-rails`, and `use_transactional_fixtures` is '\
-    "enabled, then records created in `#{hook}` are not automatically rolled "\
-    'back.'
+    "Beware of using `#{hook}` as it may cause state to leak between tests. " \
+      'If you are using `rspec-rails`, and `use_transactional_fixtures` is ' \
+      "enabled, then records created in `#{hook}` are not automatically " \
+      'rolled back.'
   end
 
   context 'when using before all' do
