@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-RSpec.describe RuboCop::Cop::RSpec::Capybara::FeatureMethods, :config do
+RSpec.describe RuboCop::Cop::RSpec::Capybara::FeatureMethods do
   it 'flags violations for `background`' do
     expect_offense(<<-RUBY)
       describe 'some feature' do
@@ -8,6 +8,12 @@ RSpec.describe RuboCop::Cop::RSpec::Capybara::FeatureMethods, :config do
         ^^^^^^^^^^ Use `before` instead of `background`.
       end
     RUBY
+
+    expect_correction(<<-RUBY)
+      describe 'some feature' do
+        before do; end
+      end
+    RUBY
   end
 
   it 'flags violations for `scenario`' do
@@ -17,6 +23,12 @@ RSpec.describe RuboCop::Cop::RSpec::Capybara::FeatureMethods, :config do
         ^^^^^^^^ Use `it` instead of `scenario`.
       end
     RUBY
+
+    expect_correction(<<-RUBY)
+      RSpec.describe 'some feature' do
+        it 'Foo' do; end
+      end
+    RUBY
   end
 
   it 'flags violations for `xscenario`' do
@@ -26,6 +38,12 @@ RSpec.describe RuboCop::Cop::RSpec::Capybara::FeatureMethods, :config do
               ^^^^^^^^^ Use `xit` instead of `xscenario`.
       end
     RUBY
+
+    expect_correction(<<-RUBY)
+      describe 'Foo' do
+        RSpec.xit 'Baz' do; end
+      end
+    RUBY
   end
 
   it 'flags violations for `given`' do
@@ -35,6 +53,12 @@ RSpec.describe RuboCop::Cop::RSpec::Capybara::FeatureMethods, :config do
         ^^^^^ Use `let` instead of `given`.
       end
     RUBY
+
+    expect_correction(<<-RUBY)
+      RSpec.describe 'Foo' do
+        let(:foo) { :foo }
+      end
+    RUBY
   end
 
   it 'flags violations for `given!`' do
@@ -44,6 +68,12 @@ RSpec.describe RuboCop::Cop::RSpec::Capybara::FeatureMethods, :config do
         ^^^^^^ Use `let!` instead of `given!`.
       end
     RUBY
+
+    expect_correction(<<-RUBY)
+      describe 'Foo' do
+        let!(:foo) { :foo }
+      end
+    RUBY
   end
 
   it 'flags violations for `feature`' do
@@ -51,6 +81,25 @@ RSpec.describe RuboCop::Cop::RSpec::Capybara::FeatureMethods, :config do
       RSpec.feature 'Foo' do; end
             ^^^^^^^ Use `describe` instead of `feature`.
     RUBY
+
+    expect_correction(<<-RUBY)
+      RSpec.describe 'Foo' do; end
+    RUBY
+  end
+
+  it 'flags violations inside shared groups' do
+    expect_offense(<<-RUBY)
+      RSpec.shared_examples_for 'common scenarios' do
+        feature 'Foo' do; end
+        ^^^^^^^ Use `describe` instead of `feature`.
+      end
+    RUBY
+
+    expect_correction(<<-RUBY)
+      RSpec.shared_examples_for 'common scenarios' do
+        describe 'Foo' do; end
+      end
+    RUBY
   end
 
   it 'ignores variables inside examples' do
@@ -101,26 +150,4 @@ RSpec.describe RuboCop::Cop::RSpec::Capybara::FeatureMethods, :config do
       RUBY
     end
   end
-
-  shared_examples 'autocorrect_spec' do |original, corrected|
-    original = <<-RUBY
-      describe Foo do
-        #{original}
-      end
-    RUBY
-    corrected = <<-RUBY
-      describe Foo do
-        #{corrected}
-      end
-    RUBY
-
-    include_examples 'autocorrect', original, corrected
-  end
-
-  include_examples 'autocorrect_spec', 'background { }',    'before { }'
-  include_examples 'autocorrect_spec', 'scenario { }',      'it { }'
-  include_examples 'autocorrect_spec', 'xscenario { }',     'xit { }'
-  include_examples 'autocorrect_spec', 'given(:foo) { }',   'let(:foo) { }'
-  include_examples 'autocorrect_spec', 'given!(:foo) { }',  'let!(:foo) { }'
-  include_examples 'autocorrect_spec', 'RSpec.feature { }', 'RSpec.describe { }'
 end
