@@ -1,14 +1,12 @@
 # frozen_string_literal: true
 
 RSpec.describe RuboCop::Cop::RSpec::EmptyLineAfterFinalLet do
-  subject(:cop) { described_class.new }
-
-  it 'checks for empty line after last let' do
+  it 'registers an offense for empty line after last let' do
     expect_offense(<<-RUBY)
       RSpec.describe User do
         let(:a) { a }
         let(:b) { b }
-        ^^^^^^^^^^^^^ Add an empty line after the last `let` block.
+        ^^^^^^^^^^^^^ Add an empty line after the last `let`.
         it { expect(a).to eq(b) }
       end
     RUBY
@@ -23,14 +21,14 @@ RSpec.describe RuboCop::Cop::RSpec::EmptyLineAfterFinalLet do
     RUBY
   end
 
-  it 'check for empty line after the last `let!`' do
+  it 'registers an offense for empty line after the last `let!`' do
     expect_offense(<<-RUBY)
       RSpec.describe User do
         let(:a) { a }
         let!(:b) do
           b
         end
-        ^^^ Add an empty line after the last `let` block.
+        ^^^ Add an empty line after the last `let!`.
         it { expect(a).to eq(b) }
       end
     RUBY
@@ -47,12 +45,12 @@ RSpec.describe RuboCop::Cop::RSpec::EmptyLineAfterFinalLet do
     RUBY
   end
 
-  it 'checks for empty line after let with proc argument' do
+  it 'registers an offense for empty line after let with proc argument' do
     expect_offense(<<-RUBY)
       RSpec.describe User do
         let(:a) { a }
         let(:user, &args[:build_user])
-        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Add an empty line after the last `let` block.
+        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Add an empty line after the last `let`.
         it { expect(a).to eq(b) }
       end
     RUBY
@@ -67,41 +65,20 @@ RSpec.describe RuboCop::Cop::RSpec::EmptyLineAfterFinalLet do
     RUBY
   end
 
-  it 'approves empty line after let' do
+  it 'does not register an offense for empty line after let' do
     expect_no_offenses(<<-RUBY)
-    RSpec.describe User do
-      let(:a) { a }
-      let(:b) { b }
-
-      it { expect(a).to eq(b) }
-    end
-    RUBY
-  end
-
-  it 'allows comment followed by an empty line after let' do
-    expect_no_offenses(<<-RUBY)
-    RSpec.describe User do
-      let(:a) { a }
-      let(:b) { b }
-      # end of setup
-
-      it { expect(a).to eq(b) }
-    end
-    RUBY
-  end
-
-  it 'flags missing empty line after the comment that comes after last let' do
-    expect_offense(<<-RUBY)
       RSpec.describe User do
         let(:a) { a }
         let(:b) { b }
-        # end of setup
-        ^^^^^^^^^^^^^^ Add an empty line after the last `let` block.
+
         it { expect(a).to eq(b) }
       end
     RUBY
+  end
 
-    expect_correction(<<-RUBY)
+  it 'does not register an offense for comment ' \
+     'followed by an empty line after let' do
+    expect_no_offenses(<<-RUBY)
       RSpec.describe User do
         let(:a) { a }
         let(:b) { b }
@@ -112,14 +89,13 @@ RSpec.describe RuboCop::Cop::RSpec::EmptyLineAfterFinalLet do
     RUBY
   end
 
-  it 'flags missing empty line after a multiline comment after last let' do
+  it 'flags a missing empty line before a comment' do
     expect_offense(<<-RUBY)
       RSpec.describe User do
         let(:a) { a }
         let(:b) { b }
-        # a multiline comment marking
-        # the end of setup
-        ^^^^^^^^^^^^^^^^^^ Add an empty line after the last `let` block.
+        ^^^^^^^^^^^^^ Add an empty line after the last `let`.
+        # comment
         it { expect(a).to eq(b) }
       end
     RUBY
@@ -128,28 +104,116 @@ RSpec.describe RuboCop::Cop::RSpec::EmptyLineAfterFinalLet do
       RSpec.describe User do
         let(:a) { a }
         let(:b) { b }
-        # a multiline comment marking
-        # the end of setup
+
+        # comment
+        it { expect(a).to eq(b) }
+      end
+    RUBY
+  end
+
+  it 'flags a missing empty line before a multiline comment' do
+    expect_offense(<<-RUBY)
+      RSpec.describe User do
+        let(:a) { a }
+        let(:b) { b }
+        ^^^^^^^^^^^^^ Add an empty line after the last `let`.
+        # multiline comment
+        # multiline comment
+        it { expect(a).to eq(b) }
+      end
+    RUBY
+
+    expect_correction(<<-RUBY)
+      RSpec.describe User do
+        let(:a) { a }
+        let(:b) { b }
+
+        # multiline comment
+        # multiline comment
+        it { expect(a).to eq(b) }
+      end
+    RUBY
+  end
+
+  it 'flags a missing empty line after a `rubocop:enable` directive' do
+    expect_offense(<<-RUBY)
+      RSpec.describe User do
+        # rubocop:disable RSpec/Foo
+        let(:a) { a }
+        let(:b) { b }
+        # rubocop:enable RSpec/Foo
+        ^^^^^^^^^^^^^^^^^^^^^^^^^^ Add an empty line after the last `let`.
+        it { expect(a).to eq(b) }
+      end
+    RUBY
+
+    expect_correction(<<-RUBY)
+      RSpec.describe User do
+        # rubocop:disable RSpec/Foo
+        let(:a) { a }
+        let(:b) { b }
+        # rubocop:enable RSpec/Foo
 
         it { expect(a).to eq(b) }
       end
     RUBY
   end
 
-  it 'ignores empty lines between the lets' do
+  it 'flags a missing empty line before a `rubocop:disable` directive' do
     expect_offense(<<-RUBY)
       RSpec.describe User do
         let(:a) { a }
-
-        subject { described_class }
-
-        let!(:b) { b }
-        ^^^^^^^^^^^^^^ Add an empty line after the last `let` block.
+        let(:b) { b }
+        ^^^^^^^^^^^^^ Add an empty line after the last `let`.
+        # rubocop:disable RSpec/Foo
         it { expect(a).to eq(b) }
+        # rubocop:enable RSpec/Foo
       end
     RUBY
 
     expect_correction(<<-RUBY)
+      RSpec.describe User do
+        let(:a) { a }
+        let(:b) { b }
+
+        # rubocop:disable RSpec/Foo
+        it { expect(a).to eq(b) }
+        # rubocop:enable RSpec/Foo
+      end
+    RUBY
+  end
+
+  it 'flags a missing empty line after a `rubocop:enable` directive ' \
+     'when it is followed by a `rubocop:disable` directive' do
+    expect_offense(<<-RUBY)
+      RSpec.describe User do
+        # rubocop:disable RSpec/Foo
+        let(:a) { a }
+        let(:b) { b }
+        # rubocop:enable RSpec/Foo
+        ^^^^^^^^^^^^^^^^^^^^^^^^^^ Add an empty line after the last `let`.
+        # rubocop:disable RSpec/Foo
+        it { expect(a).to eq(b) }
+        # rubocop:enable RSpec/Foo
+      end
+    RUBY
+
+    expect_correction(<<-RUBY)
+      RSpec.describe User do
+        # rubocop:disable RSpec/Foo
+        let(:a) { a }
+        let(:b) { b }
+        # rubocop:enable RSpec/Foo
+
+        # rubocop:disable RSpec/Foo
+        it { expect(a).to eq(b) }
+        # rubocop:enable RSpec/Foo
+      end
+    RUBY
+  end
+
+  it 'does not register an offense for empty lines between the lets' do
+    expect_no_offenses(<<-RUBY)
       RSpec.describe User do
         let(:a) { a }
 
@@ -162,7 +226,7 @@ RSpec.describe RuboCop::Cop::RSpec::EmptyLineAfterFinalLet do
     RUBY
   end
 
-  it 'handles let in tests' do
+  it 'does not register an offense for let in tests' do
     expect_no_offenses(<<-RUBY)
       RSpec.describe User do
         # This shouldn't really ever happen in a sane codebase but I still
@@ -175,7 +239,7 @@ RSpec.describe RuboCop::Cop::RSpec::EmptyLineAfterFinalLet do
     RUBY
   end
 
-  it 'handles multiline let block' do
+  it 'does not register an offense for multiline let block' do
     expect_no_offenses(<<-RUBY)
       RSpec.describe User do
         let(:a) { a }
@@ -188,7 +252,7 @@ RSpec.describe RuboCop::Cop::RSpec::EmptyLineAfterFinalLet do
     RUBY
   end
 
-  it 'handles let being the latest node' do
+  it 'does not register an offense for let being the latest node' do
     expect_no_offenses(<<-RUBY)
       RSpec.describe User do
         let(:a) { a }
@@ -197,7 +261,7 @@ RSpec.describe RuboCop::Cop::RSpec::EmptyLineAfterFinalLet do
     RUBY
   end
 
-  it 'handles HEREDOC for let' do
+  it 'does not register an offense for HEREDOC for let' do
     expect_no_offenses(<<-RUBY)
       RSpec.describe User do
         let(:foo) do
@@ -214,7 +278,7 @@ RSpec.describe RuboCop::Cop::RSpec::EmptyLineAfterFinalLet do
     RUBY
   end
 
-  it 'handles silly HEREDOC syntax for let' do
+  it 'does not register an offense for silly HEREDOC syntax for let' do
     expect_no_offenses(<<-RUBY)
       RSpec.describe 'silly heredoc syntax' do
         let(:foo) { <<-BAR }
@@ -229,14 +293,14 @@ RSpec.describe RuboCop::Cop::RSpec::EmptyLineAfterFinalLet do
     RUBY
   end
 
-  it 'handles silly HEREDOC offense' do
+  it 'registers an offense for silly HEREDOC offense' do
     expect_offense(<<-RUBY)
       RSpec.describe 'silly heredoc syntax' do
         let(:foo) { <<-BAR }
         hello
         world
         BAR
-        ^^^ Add an empty line after the last `let` block.
+        ^^^ Add an empty line after the last `let`.
         it 'has tricky syntax' do
           expect(foo).to eql("  hello\n  world\n")
         end
