@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-RSpec.describe RuboCop::Cop::RSpec::ExampleWording, :config do
+RSpec.describe RuboCop::Cop::RSpec::ExampleWording do
   it 'ignores non-example blocks' do
     expect_no_offenses('foo "should do something" do; end')
   end
@@ -44,7 +44,7 @@ RSpec.describe RuboCop::Cop::RSpec::ExampleWording, :config do
     RUBY
   end
 
-  it 'finds description with `shouldn\'t` at the beginning' do
+  it "finds description with `shouldn't` at the beginning" do
     expect_offense(<<-RUBY)
       it "shouldn't do something" do
           ^^^^^^^^^^^^^^^^^^^^^^ Do not use should when describing your tests.
@@ -57,7 +57,7 @@ RSpec.describe RuboCop::Cop::RSpec::ExampleWording, :config do
     RUBY
   end
 
-  it 'finds description with `SHOULDN\'T` at the beginning' do
+  it "finds description with `SHOULDN'T` at the beginning" do
     expect_offense(<<-RUBY)
       it "SHOULDN'T do something" do
           ^^^^^^^^^^^^^^^^^^^^^^ Do not use should when describing your tests.
@@ -152,8 +152,8 @@ RSpec.describe RuboCop::Cop::RSpec::ExampleWording, :config do
 
   it 'flags \-separated multiline strings' do
     expect_offense(<<-RUBY)
-      it 'should do something '\\
-          ^^^^^^^^^^^^^^^^^^^^^^ Do not use should when describing your tests.
+      it 'should do something ' \\
+          ^^^^^^^^^^^^^^^^^^^^^^^ Do not use should when describing your tests.
           'and correctly fix' do
       end
     RUBY
@@ -166,8 +166,8 @@ RSpec.describe RuboCop::Cop::RSpec::ExampleWording, :config do
 
   it 'flags \-separated multiline interpolated strings' do
     expect_offense(<<-'RUBY')
-      it "should do something "\
-          ^^^^^^^^^^^^^^^^^^^^^^ Do not use should when describing your tests.
+      it "should do something " \
+          ^^^^^^^^^^^^^^^^^^^^^^^ Do not use should when describing your tests.
           "with #{object}" do
       end
     RUBY
@@ -177,4 +177,75 @@ RSpec.describe RuboCop::Cop::RSpec::ExampleWording, :config do
       end
     RUBY
   end
+
+  it 'ignores heredocs' do
+    expect_offense(<<-'RUBY')
+      it <<~DESC do
+          ^^^^^ Do not use should when describing your tests.
+        should not start with this word
+      DESC
+      end
+    RUBY
+  end
+
+  it 'flags an unclear description' do
+    expect_offense(<<-'RUBY')
+      it "works" do
+          ^^^^^ Your example description is insufficient.
+      end
+    RUBY
+  end
+
+  it 'flags an unclear description despite extra spaces' do
+    expect_offense(<<-'RUBY')
+      it "  works    " do
+          ^^^^^^^^^^^ Your example description is insufficient.
+      end
+    RUBY
+  end
+
+  it 'flags an unclear description despite uppercase and lowercase strings' do
+    expect_offense(<<-'RUBY')
+      it "WOrKs " do
+          ^^^^^^ Your example description is insufficient.
+      end
+    RUBY
+  end
+
+  context 'when `DisallowedExamples: Workz`' do
+    let(:cop_config) { { 'DisallowedExamples' => ['Workz'] } }
+
+    it 'finds a valid sentence across two lines' do
+      expect_no_offenses(<<-'RUBY')
+        it "workz " \
+          "totally fine " do
+        end
+      RUBY
+    end
+
+    it 'finds an invalid example across two lines' do
+      expect_offense(<<-'RUBY')
+        it "workz" \
+            ^^^^^^^^ Your example description is insufficient.
+          " " do
+        end
+      RUBY
+    end
+
+    it 'flags an unclear description' do
+      expect_offense(<<-'RUBY')
+        it "workz" do
+            ^^^^^ Your example description is insufficient.
+        end
+      RUBY
+    end
+
+    it 'flags an unclear description despite uppercase and lowercase strings' do
+      expect_offense(<<-'RUBY')
+        it "WOrKz " do
+            ^^^^^^ Your example description is insufficient.
+        end
+      RUBY
+    end
+  end
 end
