@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-RSpec.describe RuboCop::Cop::RSpec::HookArgument, :config do
+RSpec.describe RuboCop::Cop::RSpec::HookArgument do
   let(:cop_config) do
     { 'EnforcedStyle' => enforced_style }
   end
@@ -28,19 +28,6 @@ RSpec.describe RuboCop::Cop::RSpec::HookArgument, :config do
     end
   end
 
-  shared_examples 'hook autocorrect' do |output|
-    include_examples 'autocorrect', 'before(:each) { }', output
-    include_examples 'autocorrect', 'before(:example) { }', output
-    include_examples 'autocorrect', 'before { }', output
-
-    include_examples 'autocorrect', 'config.before(:each) { }',
-                     'config.' + output
-    include_examples 'autocorrect', 'config.before(:example) { }',
-                     'config.' + output
-    include_examples 'autocorrect', 'config.before { }',
-                     'config.' + output
-  end
-
   shared_examples 'an example hook' do
     include_examples 'ignored hooks'
     include_examples 'detects style', 'before(:each) { foo }', 'each'
@@ -55,47 +42,91 @@ RSpec.describe RuboCop::Cop::RSpec::HookArgument, :config do
       expect_offense(<<-RUBY)
         before(:each) { true }
         ^^^^^^^^^^^^^ Omit the default `:each` argument for RSpec hooks.
-        after(:each)  { true }
+        after(:each) { true }
         ^^^^^^^^^^^^ Omit the default `:each` argument for RSpec hooks.
         around(:each) { true }
         ^^^^^^^^^^^^^ Omit the default `:each` argument for RSpec hooks.
-        config.after(:each)  { true }
+        config.after(:each) { true }
         ^^^^^^^^^^^^^^^^^^^ Omit the default `:each` argument for RSpec hooks.
       RUBY
+
+      expect_correction(<<-RUBY)
+        before { true }
+        after { true }
+        around { true }
+        config.after { true }
+      RUBY
     end
 
     it 'detects :example for hooks' do
       expect_offense(<<-RUBY)
         before(:example) { true }
         ^^^^^^^^^^^^^^^^ Omit the default `:example` argument for RSpec hooks.
-        after(:example)  { true }
+        after(:example) { true }
         ^^^^^^^^^^^^^^^ Omit the default `:example` argument for RSpec hooks.
         around(:example) { true }
         ^^^^^^^^^^^^^^^^ Omit the default `:example` argument for RSpec hooks.
         config.before(:example) { true }
         ^^^^^^^^^^^^^^^^^^^^^^^ Omit the default `:example` argument for RSpec hooks.
       RUBY
+
+      expect_correction(<<-RUBY)
+        before { true }
+        after { true }
+        around { true }
+        config.before { true }
+      RUBY
     end
 
     it 'does not flag hooks without default scopes' do
       expect_no_offenses(<<-RUBY)
         before { true }
         after { true }
+        around { true }
         config.before { true }
       RUBY
     end
 
     include_examples 'an example hook'
-    include_examples 'hook autocorrect', 'before { }'
+
+    context 'when Ruby 2.7', :ruby27 do
+      it 'detects :each for hooks' do
+        expect_offense(<<-RUBY)
+          around(:each) { _1 }
+          ^^^^^^^^^^^^^ Omit the default `:each` argument for RSpec hooks.
+        RUBY
+
+        expect_correction(<<-RUBY)
+          around { _1 }
+        RUBY
+      end
+
+      it 'detects :example for hooks' do
+        expect_offense(<<-RUBY)
+          around(:example) { _1 }
+          ^^^^^^^^^^^^^^^^ Omit the default `:example` argument for RSpec hooks.
+        RUBY
+
+        expect_correction(<<-RUBY)
+          around { _1 }
+        RUBY
+      end
+
+      it 'does not flag hooks without default scopes' do
+        expect_no_offenses(<<-RUBY)
+          around { _1 }
+        RUBY
+      end
+    end
   end
 
   context 'when EnforcedStyle is :each' do
     let(:enforced_style) { :each }
 
-    it 'detects :each for hooks' do
+    it 'does not flag :each for hooks' do
       expect_no_offenses(<<-RUBY)
         before(:each) { true }
-        after(:each)  { true }
+        after(:each) { true }
         around(:each) { true }
         config.before(:each) { true }
       RUBY
@@ -105,13 +136,20 @@ RSpec.describe RuboCop::Cop::RSpec::HookArgument, :config do
       expect_offense(<<-RUBY)
         before(:example) { true }
         ^^^^^^^^^^^^^^^^ Use `:each` for RSpec hooks.
-        after(:example)  { true }
+        after(:example) { true }
         ^^^^^^^^^^^^^^^ Use `:each` for RSpec hooks.
         around(:example) { true }
         ^^^^^^^^^^^^^^^^ Use `:each` for RSpec hooks.
         config.before(:example) { true }
         ^^^^^^^^^^^^^^^^^^^^^^^ Use `:each` for RSpec hooks.
       RUBY
+
+      expect_correction(<<-RUBY)
+        before(:each) { true }
+        after(:each) { true }
+        around(:each) { true }
+        config.before(:each) { true }
+      RUBY
     end
 
     it 'detects hooks without default scopes' do
@@ -120,22 +158,60 @@ RSpec.describe RuboCop::Cop::RSpec::HookArgument, :config do
         ^^^^^^ Use `:each` for RSpec hooks.
         after { true }
         ^^^^^ Use `:each` for RSpec hooks.
+        around { true }
+        ^^^^^^ Use `:each` for RSpec hooks.
         config.before { true }
                ^^^^^^ Use `:each` for RSpec hooks.
       RUBY
+
+      expect_correction(<<-RUBY)
+        before(:each) { true }
+        after(:each) { true }
+        around(:each) { true }
+        config.before(:each) { true }
+      RUBY
     end
 
     include_examples 'an example hook'
-    include_examples 'hook autocorrect', 'before(:each) { }'
+
+    context 'when Ruby 2.7', :ruby27 do
+      it 'does not flag :each for hooks' do
+        expect_no_offenses(<<-RUBY)
+          around(:each) { _1 }
+        RUBY
+      end
+
+      it 'detects :example for hooks' do
+        expect_offense(<<-RUBY)
+          around(:example) { _1 }
+          ^^^^^^^^^^^^^^^^ Use `:each` for RSpec hooks.
+        RUBY
+
+        expect_correction(<<-RUBY)
+          around(:each) { _1 }
+        RUBY
+      end
+
+      it 'detects hooks without default scopes' do
+        expect_offense(<<-RUBY)
+          around { _1 }
+          ^^^^^^ Use `:each` for RSpec hooks.
+        RUBY
+
+        expect_correction(<<-RUBY)
+          around(:each) { _1 }
+        RUBY
+      end
+    end
   end
 
   context 'when EnforcedStyle is :example' do
     let(:enforced_style) { :example }
 
-    it 'detects :example for hooks' do
+    it 'does not flag :example for hooks' do
       expect_no_offenses(<<-RUBY)
         before(:example) { true }
-        after(:example)  { true }
+        after(:example) { true }
         around(:example) { true }
         config.before(:example) { true }
       RUBY
@@ -145,27 +221,72 @@ RSpec.describe RuboCop::Cop::RSpec::HookArgument, :config do
       expect_offense(<<-RUBY)
         before(:each) { true }
         ^^^^^^^^^^^^^ Use `:example` for RSpec hooks.
-        after(:each)  { true }
+        after(:each) { true }
         ^^^^^^^^^^^^ Use `:example` for RSpec hooks.
         around(:each) { true }
         ^^^^^^^^^^^^^ Use `:example` for RSpec hooks.
         config.before(:each) { true }
         ^^^^^^^^^^^^^^^^^^^^ Use `:example` for RSpec hooks.
       RUBY
+
+      expect_correction(<<-RUBY)
+        before(:example) { true }
+        after(:example) { true }
+        around(:example) { true }
+        config.before(:example) { true }
+      RUBY
     end
 
-    it 'does not flag hooks without default scopes' do
+    it 'detects hooks without default scopes' do
       expect_offense(<<-RUBY)
         before { true }
         ^^^^^^ Use `:example` for RSpec hooks.
         after { true }
         ^^^^^ Use `:example` for RSpec hooks.
+        around { true }
+        ^^^^^^ Use `:example` for RSpec hooks.
         config.before { true }
                ^^^^^^ Use `:example` for RSpec hooks.
       RUBY
+
+      expect_correction(<<-RUBY)
+        before(:example) { true }
+        after(:example) { true }
+        around(:example) { true }
+        config.before(:example) { true }
+      RUBY
     end
 
     include_examples 'an example hook'
-    include_examples 'hook autocorrect', 'before(:example) { }'
+
+    context 'when Ruby 2.7', :ruby27 do
+      it 'does not flag :example for hooks' do
+        expect_no_offenses(<<-RUBY)
+          around(:example) { _1 }
+        RUBY
+      end
+
+      it 'detects :each for hooks' do
+        expect_offense(<<-RUBY)
+          around(:each) { _1 }
+          ^^^^^^^^^^^^^ Use `:example` for RSpec hooks.
+        RUBY
+
+        expect_correction(<<-RUBY)
+          around(:example) { _1 }
+        RUBY
+      end
+
+      it 'detects hooks without default scopes' do
+        expect_offense(<<-RUBY)
+          around { _1 }
+          ^^^^^^ Use `:example` for RSpec hooks.
+        RUBY
+
+        expect_correction(<<-RUBY)
+          around(:example) { _1 }
+        RUBY
+      end
+    end
   end
 end
