@@ -1,8 +1,6 @@
 # frozen_string_literal: true
 
 RSpec.describe RuboCop::Cop::RSpec::InstanceSpy do
-  subject(:cop) { described_class.new }
-
   context 'when used with `have_received`' do
     it 'adds an offense for an instance_double with single argument' do
       expect_offense(<<-RUBY)
@@ -49,7 +47,7 @@ RSpec.describe RuboCop::Cop::RSpec::InstanceSpy do
   end
 
   context 'when not used with `have_received`' do
-    it 'does not add an offence' do
+    it 'does not add an offense' do
       expect_no_offenses(<<-RUBY)
         it do
           foo = instance_double(Foo).as_null_object
