@@ -1,8 +1,6 @@
 # frozen_string_literal: true
 
 RSpec.describe RuboCop::Cop::RSpec::LetBeforeExamples do
-  subject(:cop) { described_class.new }
-
   it 'flags `let` after `it`' do
     expect_offense(<<-RUBY)
       RSpec.describe User do
@@ -43,10 +41,26 @@ RSpec.describe RuboCop::Cop::RSpec::LetBeforeExamples do
     RUBY
   end
 
-  it 'flags `let` after `include_examples`' do
+  it 'flags `let` after `include_examples`, but does not autocorrect' do
+    # NOTE: include_examples may define the same variable as `let`,
+    # and changing the order may break the spec due to order dependency
+    # if `let` is moved above.
     expect_offense(<<-RUBY)
       RSpec.describe User do
-        include_examples('should be after let')
+        include_examples('should be BEFORE let as it defines `let(:foo)`, too')
+
+        let(:foo) { 'bar' }
+        ^^^^^^^^^^^^^^^^^^^ Move `let` before the examples in the group.
+      end
+    RUBY
+
+    expect_no_corrections
+  end
+
+  it 'flags `let` after `it_behaves_like`' do
+    expect_offense(<<-RUBY)
+      RSpec.describe User do
+        it_behaves_like('should be after let')
 
         let(:foo) { bar }
         ^^^^^^^^^^^^^^^^^ Move `let` before the examples in the group.
@@ -56,7 +70,7 @@ RSpec.describe RuboCop::Cop::RSpec::LetBeforeExamples do
     expect_correction(<<-RUBY)
       RSpec.describe User do
         let(:foo) { bar }
-        include_examples('should be after let')
+        it_behaves_like('should be after let')
 
       end
     RUBY
@@ -65,7 +79,7 @@ RSpec.describe RuboCop::Cop::RSpec::LetBeforeExamples do
   it 'flags `let` with proc argument' do
     expect_offense(<<-RUBY)
       RSpec.describe User do
-        include_examples('should be after let')
+        it_behaves_like('should be after let')
 
         let(:user, &args[:build_user])
         ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Move `let` before the examples in the group.
@@ -75,7 +89,30 @@ RSpec.describe RuboCop::Cop::RSpec::LetBeforeExamples do
     expect_correction(<<-RUBY)
       RSpec.describe User do
         let(:user, &args[:build_user])
-        include_examples('should be after let')
+        it_behaves_like('should be after let')
+
+      end
+    RUBY
+  end
+
+  it 'flags `let` with a heredoc argument' do
+    expect_offense(<<-RUBY)
+      RSpec.describe User do
+        it_behaves_like('should be after let')
+
+        let(:foo) { (<<-SOURCE) }
+        ^^^^^^^^^^^^^^^^^^^^^^^^^ Move `let` before the examples in the group.
+        some long text here
+        SOURCE
+      end
+    RUBY
+
+    expect_correction(<<-RUBY)
+      RSpec.describe User do
+        let(:foo) { (<<-SOURCE) }
+        some long text here
+        SOURCE
+        it_behaves_like('should be after let')
 
       end
     RUBY
@@ -92,7 +129,7 @@ RSpec.describe RuboCop::Cop::RSpec::LetBeforeExamples do
           it { is_expected.to work }
         end
 
-        include_examples('everything is fine')
+        it_behaves_like('everything is fine')
       end
     RUBY
   end
@@ -107,7 +144,7 @@ RSpec.describe RuboCop::Cop::RSpec::LetBeforeExamples do
           it { is_expected.to work }
         end
 
-        include_examples('everything is fine')
+        it_behaves_like('everything is fine')
       end
     RUBY
   end
@@ -125,32 +162,10 @@ RSpec.describe RuboCop::Cop::RSpec::LetBeforeExamples do
   it 'ignores single-line example blocks' do
     expect_no_offenses(<<-RUBY)
       RSpec.describe User do
-        include_examples 'special user' do
+        it_behaves_like 'special user' do
           let(:foo) { bar }
         end
       end
     RUBY
   end
-
-  bad_code = <<-RUBY
-    RSpec.describe User do
-      include_examples('should be after let')
-
-      let(:foo) { (<<-SOURCE) }
-      some long text here
-      SOURCE
-    end
-  RUBY
-
-  good_code = <<-RUBY
-    RSpec.describe User do
-      let(:foo) { (<<-SOURCE) }
-      some long text here
-      SOURCE
-      include_examples('should be after let')
-
-    end
-  RUBY
-
-  include_examples 'autocorrect', bad_code, good_code
 end
