@@ -1,8 +1,6 @@
 # frozen_string_literal: true
 
 RSpec.describe RuboCop::Cop::RSpec::SubjectStub do
-  subject(:cop) { described_class.new }
-
   it 'flags when subject is stubbed' do
     expect_offense(<<-RUBY)
       describe Foo do
@@ -76,6 +74,45 @@ RSpec.describe RuboCop::Cop::RSpec::SubjectStub do
     RUBY
   end
 
+  it 'flags when a forced subject! is mocked and called as subject' do
+    expect_offense(<<-RUBY)
+      describe Foo do
+        subject!(:foo) { described_class.new }
+
+        it 'uses bang subject!' do
+          expect(subject).to receive(:bar)
+          ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Do not stub methods of the object under test.
+        end
+      end
+    RUBY
+  end
+
+  it 'flags when a forced subject! is mocked and called by name' do
+    expect_offense(<<-RUBY)
+      describe Foo do
+        subject!(:foo) { described_class.new }
+
+        it 'uses bang subject! by name' do
+          expect(foo).to receive(:bar)
+          ^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Do not stub methods of the object under test.
+        end
+      end
+    RUBY
+  end
+
+  it 'flags when an unnamed forced subject! is mocked' do
+    expect_offense(<<-RUBY)
+      describe Foo do
+        subject! { described_class.new }
+
+        it 'uses bang subject!' do
+          expect(subject).to receive(:bar)
+          ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Do not stub methods of the object under test.
+        end
+      end
+    RUBY
+  end
+
   it 'flags an expectation made on an unnamed subject' do
     expect_offense(<<-RUBY)
       describe Foo do
@@ -89,7 +126,7 @@ RSpec.describe RuboCop::Cop::RSpec::SubjectStub do
     RUBY
   end
 
-  it 'flags one-line expectcation syntax' do
+  it 'flags one-line expectation syntax' do
     expect_offense(<<-RUBY)
       describe Foo do
         subject(:foo) { described_class.new }
@@ -102,8 +139,8 @@ RSpec.describe RuboCop::Cop::RSpec::SubjectStub do
     RUBY
   end
 
-  it 'ignores stub within context where subject name changed' do
-    expect_no_offenses(<<-RUBY)
+  it 'flags stub within context where subject name changed' do
+    expect_offense(<<-RUBY)
       describe Foo do
         subject(:foo) { described_class.new }
 
@@ -112,6 +149,7 @@ RSpec.describe RuboCop::Cop::RSpec::SubjectStub do
 
           it 'tries to trick rubocop-rspec' do
             allow(foo).to receive(:baz)
+            ^^^^^^^^^^^^^^^^^^^^^^^^^^^ Do not stub methods of the object under test.
           end
         end
       end
@@ -151,8 +189,8 @@ RSpec.describe RuboCop::Cop::RSpec::SubjectStub do
     RUBY
   end
 
-  it 'ignores nested stubs when nested subject is anonymous' do
-    expect_no_offenses(<<-RUBY)
+  it 'flags nested stubs when nested subject is anonymous' do
+    expect_offense(<<-RUBY)
       describe Foo do
         subject(:foo) { described_class.new }
 
@@ -161,6 +199,7 @@ RSpec.describe RuboCop::Cop::RSpec::SubjectStub do
 
           before do
             allow(foo).to receive(:wow)
+            ^^^^^^^^^^^^^^^^^^^^^^^^^^^ Do not stub methods of the object under test.
           end
 
           it 'tries to trick rubocop-rspec' do
@@ -200,6 +239,7 @@ RSpec.describe RuboCop::Cop::RSpec::SubjectStub do
 
           before do
             allow(foo).to receive(:wow)
+            ^^^^^^^^^^^^^^^^^^^^^^^^^^^ Do not stub methods of the object under test.
             allow(bar).to receive(:wow)
             ^^^^^^^^^^^^^^^^^^^^^^^^^^^ Do not stub methods of the object under test.
           end
@@ -242,7 +282,9 @@ RSpec.describe RuboCop::Cop::RSpec::SubjectStub do
 
             before do
               allow(foo).to receive(:wow)
+              ^^^^^^^^^^^^^^^^^^^^^^^^^^^ Do not stub methods of the object under test.
               allow(bar).to receive(:wow)
+              ^^^^^^^^^^^^^^^^^^^^^^^^^^^ Do not stub methods of the object under test.
               allow(baz).to receive(:wow)
               ^^^^^^^^^^^^^^^^^^^^^^^^^^^ Do not stub methods of the object under test.
             end
@@ -343,6 +385,54 @@ RSpec.describe RuboCop::Cop::RSpec::SubjectStub do
     RUBY
   end
 
+  it 'flags stubs inside helper methods' do
+    expect_offense(<<~RUBY)
+      RSpec.describe Bar do
+        subject(:bar) { described_class.new }
+
+        def allow_subject_to_receive_bar
+          allow(bar).to receive(:bar)
+          ^^^^^^^^^^^^^^^^^^^^^^^^^^^ Do not stub methods of the object under test.
+        end
+      end
+    RUBY
+  end
+
+  it 'ignores subjects from sibling example groups' do
+    expect_no_offenses(<<~RUBY)
+      RSpec.describe Foo do
+        describe '#bar' do
+          subject(:bar) { :bar }
+          it { }
+        end
+
+        describe '#baz' do
+          specify do
+            allow(bar).to receive(:bar)
+          end
+        end
+      end
+    RUBY
+  end
+
+  it 'ignores subjects from parent example groups redefined with let' do
+    expect_no_offenses(<<~RUBY)
+      RSpec.describe Foo do
+        subject(:foo) { described_class.new }
+
+        context '#bar' do
+          subject(:bar) { foo.bar }
+
+          let(:foo) { described_class.new }
+
+          before do
+            allow(foo).to receive(:active?).and_return(true)
+          end
+        end
+      end
+    RUBY
+  end
+
   describe 'top level example groups' do
     %i[
       describe xdescribe fdescribe
