@@ -6,14 +6,19 @@ RSpec.describe RuboCop::RSpec::ConfigFormatter do
   let(:config) do
     {
       'AllCops' => {
-        'Setting' => 'fourty two'
+        'Setting' => 'forty two'
       },
       'RSpec/Foo' => {
-        'Config'      => 2,
-        'Enabled'     => true
+        'Config' => 2,
+        'Enabled' => true
       },
       'RSpec/Bar' => {
-        'Enabled'     => true
+        'Enabled' => true,
+        'Nullable' => nil
+      },
+      'RSpec/Baz' => {
+        'Enabled' => true,
+        'StyleGuide' => '#buzz'
       }
     }
   end
@@ -25,6 +30,9 @@ RSpec.describe RuboCop::RSpec::ConfigFormatter do
       },
       'RSpec/Bar' => {
         'Description' => 'Wow'
+      },
+      'RSpec/Baz' => {
+        'Description' => 'Woof'
       }
     }
   end
@@ -35,18 +43,25 @@ RSpec.describe RuboCop::RSpec::ConfigFormatter do
     expect(formatter.dump).to eql(<<-YAML.gsub(/^\s+\|/, ''))
       |---
       |AllCops:
-      |  Setting: fourty two
+      |  Setting: forty two
       |
       |RSpec/Foo:
       |  Config: 2
       |  Enabled: true
       |  Description: Blah
-      |  StyleGuide: https://www.rubydoc.info/gems/rubocop-rspec/RuboCop/Cop/RSpec/Foo
+      |  Reference: https://www.rubydoc.info/gems/rubocop-rspec/RuboCop/Cop/RSpec/Foo
       |
       |RSpec/Bar:
       |  Enabled: true
+      |  Nullable: ~
       |  Description: Wow
-      |  StyleGuide: https://www.rubydoc.info/gems/rubocop-rspec/RuboCop/Cop/RSpec/Bar
+      |  Reference: https://www.rubydoc.info/gems/rubocop-rspec/RuboCop/Cop/RSpec/Bar
+      |
+      |RSpec/Baz:
+      |  Enabled: true
+      |  StyleGuide: "#buzz"
+      |  Description: Woof
+      |  Reference: https://www.rubydoc.info/gems/rubocop-rspec/RuboCop/Cop/RSpec/Baz
     YAML
   end
 end
